@@ -70,12 +70,19 @@ class RecordJobAdmin(admin.ModelAdmin):
             clone,
     ]
 
+    date_hierarchy = 'scheduled_start_date'
+
+    list_per_page = 200
+
+    # search_fields = ['id']
+
     exclude = ["record_source"]
     readonly_fields = [
             'insertion_date',
             'modification_date',
             'execution_date',
             'completion_date',
+            'scheduled_end_date',
     ]
 
     fieldsets = (
@@ -84,6 +91,7 @@ class RecordJobAdmin(admin.ModelAdmin):
                 (
             'sources_group',
             'scheduled_start_date',
+            'scheduled_end_date',
             'scheduled_duration',
             'enabled',
                 ),
@@ -110,19 +118,20 @@ class RecordJobAdmin(admin.ModelAdmin):
     )
 
     list_display = [
-      '__repr__',
-      'status',
-      'scheduled_duration',
+      'pretty_name',
       'scheduled_start_date',
+      'scheduled_end_date',
+      'scheduled_duration',
       'insertion_date',
       'modification_date',
       'execution_date',
+      'status',
     ]
 
     list_filter = [
             "enabled",
             "status",
-            "sources_group",
+            "record_source",
             "recorder",
     ]
 
@@ -208,7 +217,7 @@ class SourcesGroupAdmin(admin.ModelAdmin):
             'fields': (
                 (
             'name',
-            'bitrate',
+            'external_id',
                 ),
 
             )
